Module wire

Module wire 

Stream-based and datagram-based communication implementations.

Also includes other utilities useful for reading and writing parcels.

Re-exports

pub use self::middleware::Middleware;

Modules

dgram
Datagram-based over the wire communication.
middleware
A type safe Parcel data transformation pipeline.
stream
Stream-based over the wire communication.

Structs

Reader
A receive buffer that waits until enough data is ready and then returns the parsed parcels.